from .reporter import download_data, save_data
import argparse


def main():
    parser = argparse.ArgumentParser(description='Calculate revenues and costs')
    parser.add_argument('--input_file', type=str, required=True, help='Input file')
    parser.add_argument('--output_file', type=str, required=True, help='Output file')

    args = parser.parse_args()
    data = download_data(args.input_file)

    grouped_df = data.groupby('category')['amount'].sum().reset_index()


    save_data(args.output_file, grouped_df)
    print('Данные сохранены по адресу: ', args.output_file)


if __name__ == '__main__':
    main()



from setuptools import setup, find_packages

setup(
    name='data-reporter-NovEf',
    version='0.1',
    packages=find_packages(),
    install_requires=[],
    entry_points={
        'console_scripts': [
            'data-reporter-NovEf=data_reporter.__main__:main',
        ],
    },
    description='A package for calculating which will download transaction data, '
                'group them by categories (income and expenses) and generate a '
                'report with amounts for each category.',
    author='Novoselov Efim',
    author_email='kuku@mail.com'
)


import pandas as pd


def download_data(file_path):
    return pd.read_csv(file_path)

def save_data(file_path, grouped):
    with open(file_path, 'w') as file:
        for  index, row in grouped.iterrows():
            file.write(f"{row['category']}:\t{row['amount']} руб.\n")